@@ -45,8 +45,5 @@ class Object(object):
     def __repr__(self):
         return '<%s %s>' % (self.__class__.__name__, pformat(self.__dict__))
 
-    def __getattr__(self, item):
-        return self.__dict__.get(item)
-
     def datetime(self, unixtime):
-        return datetime.fromtimestamp(int(unixtime))
+        return datetime.fromtimestamp(int(unixtime))
\ No newline at end of file
