@@ -1,5 +1,4 @@
 from floraconcierge.client.types import Object
-from floraconcierge.mapping.mixins.model.shop import Currency as CurrencyMixin
 
 
 class Order(Object):
@@ -37,6 +36,7 @@ class Order(Object):
         self.receiver_email = None
         self.receiver_name = None
         self.receiver_phone = None
+        self.receiver_phone_clear = None
         self.sender_city = None
         self.sender_country = None
         self.sender_email = None
@@ -44,6 +44,7 @@ class Order(Object):
         self.sender_ip = None
         self.sender_name = None
         self.sender_phone = None
+        self.sender_phone_clear = None
         self.status = None
         self.status_changed = None
         self.status_plain = None
@@ -61,7 +62,7 @@ class Order(Object):
         super(Order, self).__init__(*args, **kwargs)
 
 
-class Currency(CurrencyMixin):
+class Currency(Object):
 
     """
     :type id: int
@@ -143,6 +144,7 @@ class Product(Object):
         self.composition = None
         self.compositions_info = None
         self.description = None
+        self.gallery = None
         self.id = None
         self.order = None
         self.price = None
