@@ -314,6 +314,35 @@ class Users(Service):
         """
         return self._callapi("users/resetpassword", get={"email": email})
 
+    def social_list(self):
+        """
+        :rtype : Stdclass
+        """
+        return self._callapi("users/social/list")
+
+    def social_login(self, token):
+        """
+        :rtype : User
+        """
+        return self._callapi("users/social/login", get={"token": token})
+
+    def social_related(self):
+        """
+        :rtype : Stdclass
+        """
+        return self._callapi("users/social/related")
+
+    def social_signin(self, service, redirect_success, redirect_fail):
+        """
+        :rtype : str
+        """
+        return self._callapi(
+            "users/social/signin",
+            get={
+                "service": service,
+                "redirect_success": redirect_success,
+                "redirect_fail": redirect_fail})
+
     def update_info(
             self,
             password=None,
@@ -411,6 +440,37 @@ class System(Service):
 # noinspection PyShadowingBuiltins
 
 
+class Auth(Service):
+
+    def set_result(self, token_id, is_success, data):
+        """
+        :rtype : Signin
+        """
+        return self._callapi(
+            "auth/result",
+            get={
+                "token_id": token_id,
+                "is_success": is_success,
+                "data": data})
+
+    def get_token(self, id):
+        """
+        :rtype : Signin
+        """
+        return self._callapi("auth/token", get={"id": id})
+# noinspection PyShadowingBuiltins
+
+
+class Phone(Service):
+
+    def search(self, phone):
+        """
+        :rtype : Stdclass
+        """
+        return self._callapi("phone/search", get={"phone": phone})
+# noinspection PyShadowingBuiltins
+
+
 class Partner(Service):
 
     def history_all_ref_codes(self, after_id=None):
@@ -560,6 +620,8 @@ class Manager(object):
         self.users = Users(apiclient)
         self.invoices = Invoices(apiclient)
         self.system = System(apiclient)
+        self.auth = Auth(apiclient)
+        self.phone = Phone(apiclient)
         self.partner = Partner(apiclient)
         self.validation = Validation(apiclient)
         self.geo = Geo(apiclient)
